pub struct CodecCache { /* private fields */ }Implementations
Sourceimpl CodecCache
impl CodecCache
Sourcepub fn ldpc(&self, code: LdpcCode) -> Arc<Ldpc> ⓘ
pub fn ldpc(&self, code: LdpcCode) -> Arc<Ldpc> ⓘ
Returns the Ldpc for code, building and caching it on first use.
Sourcepub fn bch(&self, t: usize, msg_bits: usize) -> Arc<Bch> ⓘ
pub fn bch(&self, t: usize, msg_bits: usize) -> Arc<Bch> ⓘ
Returns the shortened Bch correcting t errors with a msg_bits
message part, building and caching it on first use.
Sourcepub fn rs(&self, n: usize, n_parity: usize) -> Arc<ReedSolomon> ⓘ
pub fn rs(&self, n: usize, n_parity: usize) -> Arc<ReedSolomon> ⓘ
Returns the ReedSolomon code (n, n_parity), building and caching it
on first use.